@@ -42,7 +42,7 @@ class StreamInfo:
 			version = reader.version
 			self.channelMask = reader.read_u_int()
 			self.offset = reader.read_u_int()
-			
+
 			if version[0] < 4:  # 4.0 down
 				self.stride = reader.read_u_int()
 				self.align = reader.read_u_int()
@@ -66,38 +66,38 @@ class VertexData:
 	def __init__(self, reader):
 		self.reader = reader
 		version = reader.version
-		
+
 		if version[0] < 2018:  # 2018 down
 			self.m_CurrentChannels = reader.read_u_int()
-		
+
 		self.m_VertexCount = reader.read_u_int()
-		
+
 		if version[0] >= 4:  # 4.0 and up
 			m_ChannelsSize = reader.read_int()
 			self.m_Channels = [
-					ChannelInfo(reader)
-					for _ in range(m_ChannelsSize)
+				ChannelInfo(reader)
+				for _ in range(m_ChannelsSize)
 			]
-		
+
 		if version[0] < 5:  # 5.0 down
 			if version[0] < 4:  #
 				m_StreamsSize = 4
 			else:
 				m_StreamsSize = reader.read_int()
-			
+
 			self.m_Streams = [
-					StreamInfo(reader = reader)
-					for _ in range(m_StreamsSize)
+				StreamInfo(reader=reader)
+				for _ in range(m_StreamsSize)
 			]
-			
+
 			if version[0] < 4:  # 4.0 down
 				self.GetChannels()
 		else:  # 5.0 and up
 			self.GetStreams()
-		
+
 		self.m_DataSize = reader.read_bytes(reader.read_int())
 		reader.align_stream()
-	
+
 	def GetStreams(self):
 		streamCount = max([x.stream for x in self.m_Channels]) + 1
 		self.m_Streams = {}
@@ -110,11 +110,11 @@ class VertexData:
 					if m_Channel.dimension > 0:
 						chnMask |= 1 << chn  # Shift 1UInt << chn
 					stride += m_Channel.dimension * MeshHelper.GetChannelFormatSize(m_Channel.format)
-			self.m_Streams[s] = StreamInfo(channelMask = chnMask, offset = offset, stride = stride, dividerOp = 0, frequency = 0)
+			self.m_Streams[s] = StreamInfo(channelMask=chnMask, offset=offset, stride=stride, dividerOp=0, frequency=0)
 			offset += self.m_VertexCount * stride
 			# static size_t align_streamSize (size_t size) { return (size + (kVertexStreamAlign-1)) & ~(kVertexStreamAlign-1)
 			offset = (offset + (16 - 1)) & ~(16 - 1)  # (offset + (16u - 1u)) & ~(16u - 1u);
-	
+
 	def GetChannels(self):
 		self.m_Channels = []  # ChannelInfo[6]
 		for i in range(6):
@@ -144,14 +144,15 @@ class VertexData:
 						m_Channel.format = 0  # kChannelFormatFloat
 						m_Channel.dimension = 4
 					offset += m_Channel.dimension * MeshHelper.GetChannelFormatSize(m_Channel.format)
-	
+
 	def FixChannel(self):
-		if any([x.dimension > 4 for x in self.m_Channels]):  # m_Channels.FirstOrDefault(x => x.dimension > 4) != null: #
+		if any(
+			[x.dimension > 4 for x in self.m_Channels]):  # m_Channels.FirstOrDefault(x => x.dimension > 4) != null: #
 			fixStream = max([x.stream for x in self.m_Channels])  # m_Channels.Max(x => x.stream)
 			fixChannels = [
-					x
-					for x in self.m_Channels
-					if x.dimension > 0 and x.stream == fixStream
+				x
+				for x in self.m_Channels
+				if x.dimension > 0 and x.stream == fixStream
 			]
 			stride = 0
 			for i, curChannel in enumerate(fixChannels):
@@ -169,7 +170,7 @@ class VertexData:
 
 
 class BoneWeights4:
-	def __init__(self, reader = None):
+	def __init__(self, reader=None):
 		if reader:
 			self.weight = reader.read_float_array(4)
 			self.boneIndex = reader.read_int_array(4)
@@ -189,7 +190,7 @@ class BlendShapeVertex:
 class MeshBlendShape:
 	def __init__(self, reader):
 		version = reader.version
-		
+
 		if version[0] == 4 and version[1] < 3:  # 4.3 down
 			self.name = reader.read_aligned_string()
 		self.firstVertex = reader.read_u_int()
@@ -214,54 +215,54 @@ class MeshBlendShapeChannel:
 class BlendShapeData:
 	def __init__(self, reader):
 		version = reader.version
-		
+
 		if version[0] > 4 or (version[0] == 4 and version[1] >= 3):  # 4.3 and up
 			numVerts = reader.read_int()
 			self.vertices = [
-					BlendShapeVertex(reader)
-					for _ in range(numVerts)
+				BlendShapeVertex(reader)
+				for _ in range(numVerts)
 			]
-			
+
 			numShapes = reader.read_int()
 			self.shapes = [
-					MeshBlendShape(reader)
-					for _ in range(numShapes)
+				MeshBlendShape(reader)
+				for _ in range(numShapes)
 			]
-			
+
 			numChannels = reader.read_int()
 			self.channels = [
-					MeshBlendShapeChannel(reader)
-					for _ in range(numChannels)
+				MeshBlendShapeChannel(reader)
+				for _ in range(numChannels)
 			]
 			self.fullWeights = reader.read_float_array()
 		else:
 			m_ShapesSize = reader.read_int()
 			self.m_Shapes = [
-					MeshBlendShape(reader)
-					for _ in range(m_ShapesSize)
+				MeshBlendShape(reader)
+				for _ in range(m_ShapesSize)
 			]
 			reader.align_stream()
 			m_ShapeVerticesSize = reader.read_int()
 			self.m_ShapeVertices = [
-					BlendShapeVertex(reader)
-					for _ in range(m_ShapeVerticesSize)
+				BlendShapeVertex(reader)
+				for _ in range(m_ShapeVerticesSize)
 			]
 
 
 class SubMesh:
 	def __init__(self, reader):
 		version = reader.version
-		
+
 		self.firstByte = reader.read_u_int()
 		self.indexCount = reader.read_u_int()
 		self.topology = reader.read_int()
-		
+
 		if version[0] < 4:  # 4.0 down
 			self.triangleCount = reader.read_u_int()
-		
+
 		if version[0] > 2017 or (version[0] == 2017 and version[1] >= 3):  # 2017.3 and up
 			self.baseVertex = reader.read_u_int()
-		
+
 		if version[0] >= 3:  # 3.0 and up
 			self.firstVertex = reader.read_u_int()
 			self.vertexCount = reader.read_u_int()
@@ -269,50 +270,52 @@ class SubMesh:
 
 
 class Mesh(NamedObject):
+	m_StreamData : None
+
 	def __init__(self, reader):
-		super().__init__(reader = reader)
+		super().__init__(reader=reader)
 		version = reader.version
 		self.m_Use16BitIndices = True
 		self.m_Indices = []
-		
+
 		if version[0] < 3 or (version[0] == 3 and version[1] < 5):  # 3.5 down
 			self.m_Use16BitIndices = reader.read_int() > 0
-		
+
 		if version[0] == 2 and version[1] <= 5:  # 2.5 and down
 			m_IndexBuffer_size = reader.read_int()
-			
+
 			if self.m_Use16BitIndices:  #
 				self.m_IndexBuffer = [
-						reader.read_u_short()
-						for _ in range(math.ceil(m_IndexBuffer_size / 2))
+					reader.read_u_short()
+					for _ in range(math.ceil(m_IndexBuffer_size / 2))
 				]
 				reader.align_stream()
 			else:
 				self.m_IndexBuffer = reader.read_u_int_array(m_IndexBuffer_size // 4)
-		
+
 		m_SubMeshesSize = reader.read_int()
 		self.m_SubMeshes = [
-				SubMesh(reader)
-				for _ in range(m_SubMeshesSize)
+			SubMesh(reader)
+			for _ in range(m_SubMeshesSize)
 		]
-		
+
 		if version[0] > 4 or (version[0] == 4 and version[1] >= 1):  # 4.1 and up
 			self.m_Shapes = BlendShapeData(reader)
-		
+
 		if version[0] > 4 or (version[0] == 4 and version[1] >= 3):  # 4.3 and up
 			self.m_BindPose = reader.read_matrix_array()
 			self.m_BoneNameHashes = reader.read_u_int_array()
 			self.m_RootBoneNameHash = reader.read_u_int()
-		
+
 		if version[0] > 2 or (version[0] == 2 and version[1] >= 6):  # 2.6.0 and up
 			if version[0] >= 2019:  # 2019 and up
 				m_BonesAABBSize = reader.read_int()
 				self.m_BonesAABB = [
-						MinMaxAABB(reader)
-						for _ in range(m_BonesAABBSize)
+					MinMaxAABB(reader)
+					for _ in range(m_BonesAABBSize)
 				]
 				self.m_VariableBoneCountWeights = reader.read_u_int_array()
-			
+
 			self.m_MeshCompression = reader.read_byte()
 			if version[0] >= 4:  #
 				if version[0] < 5:  #
@@ -321,37 +324,39 @@ class Mesh(NamedObject):
 				self.m_KeepVertices = reader.read_boolean()
 				self.m_KeepIndices = reader.read_boolean()
 			reader.align_stream()
-			
+
 			# Unity fixed it in 2017.3.1p1 and later versions
 			if ((version[0] > 2017 or (version[0] == 2017 and version[1] >= 4))  # 2017.4
-					or ((version[0] == 2017 and version[1] == 3 and version[2] == 1) and self.build_type.IsPatch)  # fixed after 2017.3.1px
-					or ((version[0] == 2017 and version[1] == 3) and self.m_MeshCompression == 0)):  # 2017.3.xfx with no compression
+				or ((version[0] == 2017 and version[1] == 3 and version[
+					2] == 1) and self.build_type.IsPatch)  # fixed after 2017.3.1px
+				or ((version[0] == 2017 and version[
+					1] == 3) and self.m_MeshCompression == 0)):  # 2017.3.xfx with no compression
 				self.m_IndexFormat = reader.read_int()
-			
+
 			m_IndexBuffer_size = reader.read_int()
 			if self.m_Use16BitIndices:
 				self.m_IndexBuffer = [
-						reader.read_u_short()
-						for _ in range(m_IndexBuffer_size // 2)
+					reader.read_u_short()
+					for _ in range(m_IndexBuffer_size // 2)
 				]
 				reader.align_stream()
 			else:
 				self.m_IndexBuffer = reader.read_u_int_array(m_IndexBuffer_size // 4)
-		
+
 		if version[0] < 3 or (version[0] == 3 and version[1] < 5):  # 3.4.2 and earlier
 			m_VertexCount = reader.read_int()
 			self.m_Vertices = reader.read_float_array(m_VertexCount * 3)  # Vector3
-			
+
 			m_SkinSize = reader.read_int()
 			self.m_Skin = [
-					BoneWeights4(reader)
-					for _ in range(m_SkinSize)
+				BoneWeights4(reader)
+				for _ in range(m_SkinSize)
 			]
-			
+
 			self.m_BindPose = reader.read_matrix_array()
 			self.m_UV0 = reader.read_float_array(reader.read_int() * 2)  # Vector2
 			self.m_UV1 = reader.read_float_array(reader.read_int() * 2)  # Vector2
-			
+
 			if version[0] == 2 and version[1] <= 5:  # 2.5 and down
 				m_TangentSpace_size = reader.read_int()
 				self.m_Normals = [0] * (m_TangentSpace_size * 3)
@@ -371,55 +376,56 @@ class Mesh(NamedObject):
 			if version[0] < 2018 or (version[0] == 2018 and version[1] < 2):  # 2018.2 down
 				m_SkinSize = reader.read_int()
 				self.m_Skin = [
-						BoneWeights4(reader)
-						for _ in range(m_SkinSize)
+					BoneWeights4(reader)
+					for _ in range(m_SkinSize)
 				]
-			
+
 			if version[0] == 3 or (version[0] == 4 and version[1] <= 2):  # 4.2 and down
 				self.m_BindPose = reader.read_matrix_array()
-			
+
 			self.m_VertexData = VertexData(reader)
-		
+
 		if version[0] > 2 or (version[0] == 2 and version[1] >= 6):  # 2.6.0 and later
 			self.m_CompressedMesh = CompressedMesh(reader)
-		
+
 		self.m_LocalAABB = AABB(reader)
-		
+
 		if version[0] < 3 or (version[0] == 3 and version[1] <= 4):  # 3.4.2 and earlier
 			m_Colors_size = reader.read_int()
 			self.mColors = [
-					reader.read_byte()  # (float)reader.read_byte() / 0xFF
-					for _ in range(m_Colors_size * 4)
+				reader.read_byte()  # (float)reader.read_byte() / 0xFF
+				for _ in range(m_Colors_size * 4)
 			]
-			
+
 			m_CollisionTriangles_size = reader.read_int()
 			reader.Position += m_CollisionTriangles_size * 4  # UInt32 indices
 			m_CollisionVertexCount = reader.read_int()
-		
+
 		self.m_MeshUsageFlags = reader.read_int()
-		
+
 		if version[0] >= 5:  # 5.0 and up
 			self.m_BakedConvexCollisionMesh = reader.read_bytes(reader.read_int())
 			reader.align_stream()
 			self.m_BakedTriangleCollisionMesh = reader.read_bytes(reader.read_int())
 			reader.align_stream()
-		
+
 		if version[0] > 2018 or (version[0] == 2018 and version[1] >= 2):  # 2018.2 and up
 			self.m_MeshMetrics = [
-					reader.read_float(),
-					reader.read_float()
+				reader.read_float(),
+				reader.read_float()
 			]
-		
+
 		if version[0] > 2018 or (version[0] == 2018 and version[1] >= 3):  # 2018.3 and up
 			reader.align_stream()
 			self.m_StreamData = StreamingInfo(reader)
-		
+
 		self.ProcessData()
-	
+
 	def ProcessData(self):
-		if hasattr(self, 'm_StreamData') and self.m_StreamData.get('path'):
+		if self.m_StreamData and self.m_StreamData.path:
 			if self.m_VertexData.m_VertexCount > 0:  #
-				resourceReader = ResourceReader(self.m_StreamData.path, self.assets_file, self.m_StreamData.offset, self.m_StreamData.size)
+				resourceReader = ResourceReader(self.m_StreamData.path, self.assets_file, self.m_StreamData.offset,
+												self.m_StreamData.size)
 				self.m_VertexData.m_DataSize = resourceReader.get_data()
 		# Fix channel after 2018.3
 		version = self.version
@@ -427,12 +433,12 @@ class Mesh(NamedObject):
 			self.m_VertexData.FixChannel()
 		if version[0] > 3 or (version[0] == 3 and version[1] >= 5):  # 3.5 and up
 			self.ReadVertexData()
-		
+
 		if version[0] > 2 or (version[0] == 2 and version[1] >= 6):  # 2.6.0 and later
 			self.DecompressCompressedMesh()
-		
+
 		self.BuildFaces()
-	
+
 	def ReadVertexData(self):
 		m_VertexCount = self.m_VertexData.m_VertexCount
 		version = self.version
@@ -443,7 +449,7 @@ class Mesh(NamedObject):
 				if channelMask[chn]:
 					if version[0] < 2018 and chn == 2 and m_Channel.format == 2:  #
 						m_Channel.dimension = 4
-					
+
 					componentByteSize = MeshHelper.GetChannelFormatSize(m_Channel.format)
 					componentBytes = bytearray(m_VertexCount * m_Channel.dimension * componentByteSize)
 					for v in range(m_VertexCount):
@@ -451,19 +457,20 @@ class Mesh(NamedObject):
 						for d in range(m_Channel.dimension):
 							componentOffset = vertexOffset + componentByteSize * d
 							dstOffset = componentByteSize * (v * m_Channel.dimension + d)
-							componentBytes[dstOffset:dstOffset + componentByteSize] += self.m_VertexData.m_DataSize[componentOffset:componentOffset + componentByteSize]
-					
+							componentBytes[dstOffset:dstOffset + componentByteSize] += self.m_VertexData.m_DataSize[
+																					   componentOffset:componentOffset + componentByteSize]
+
 					if self.reader.endian == '>' and componentByteSize > 1:  # if big endian, swap bytes
 						for i in range(0, len(componentBytes), componentByteSize):
 							componentBytes[i:i + componentByteSize] = componentBytes[i:i + componentByteSize][::-1]
-					
+
 					componentsIntArray = []
 					componentsFloatArray = []
 					if m_Channel.format == 10 or m_Channel.format == 11:  #
 						componentsIntArray = MeshHelper.BytesToIntArray(componentBytes)
 					else:
 						componentsFloatArray = MeshHelper.BytesToFloatArray(componentBytes, componentByteSize)
-					
+
 					if version[0] >= 2018:  #
 						if chn == 0:  # kShaderChannelVertex
 							self.m_Vertices = componentsFloatArray
@@ -498,7 +505,7 @@ class Mesh(NamedObject):
 							for i in range(m_VertexCount):
 								for j in range(m_Channel.dimension):
 									self.m_Skin[i].boneIndex[j] = componentsIntArray[i * m_Channel.dimension + j]
-					
+
 					else:
 						if chn == 0:  # kShaderChannelVertex
 							self.m_Vertices = componentsFloatArray
@@ -519,7 +526,7 @@ class Mesh(NamedObject):
 							self.m_UV3 = componentsFloatArray
 						elif chn == 7:  # kShaderChannelTangent
 							self.m_Tangents = componentsFloatArray
-	
+
 	def DecompressCompressedMesh(self):
 		# Vertex
 		version = self.version
@@ -541,10 +548,10 @@ class Mesh(NamedObject):
 			if m_CompressedMesh.m_BindPoses.m_NumItems > 0:  #
 				m_BindPoses_Unpacked = m_CompressedMesh.m_BindPoses.UnpackFloats(16, 4 * 16)
 				self.m_BindPose = [
-						Matrix4x4(m_BindPoses_Unpacked[i:i + 16])
-						for i in range(0, m_CompressedMesh.m_BindPoses.m_NumItems, 16)
+					Matrix4x4(m_BindPoses_Unpacked[i:i + 16])
+					for i in range(0, m_CompressedMesh.m_BindPoses.m_NumItems, 16)
 				]
-		
+
 		# Normal
 		if m_CompressedMesh.m_Normals.m_NumItems > 0:
 			normalData = m_CompressedMesh.m_Normals.UnpackFloats(2, 4 * 2)
@@ -588,7 +595,7 @@ class Mesh(NamedObject):
 					z = -z
 				w = 1.0 if signs[i * 2 + 1] > 0 else -1.0
 				self.m_Tangents.extend([x, y, z, w])
-		
+
 		# FloatColor
 		if version[0] >= 5:  #
 			if m_CompressedMesh.m_FloatColors.m_NumItems > 0:  #
@@ -597,14 +604,14 @@ class Mesh(NamedObject):
 		if m_CompressedMesh.m_Weights.m_NumItems > 0:
 			weights = m_CompressedMesh.m_Weights.UnpackInts()
 			boneIndices = m_CompressedMesh.m_BoneIndices.UnpackInts()
-			
+
 			self.InitMSkin()
-			
+
 			bonePos = 0
 			boneIndexPos = 0
 			j = 0
 			sum = 0
-			
+
 			for i in range(m_CompressedMesh.m_Weights.m_NumItems):
 				# read bone index and weight.
 				self.m_Skin[bonePos].weight[j] = weights[i] / 31.0
@@ -612,7 +619,7 @@ class Mesh(NamedObject):
 				boneIndexPos += 1
 				j += 1
 				sum += weights[i]
-				
+
 				# the weights add up to one. fill the rest for this vertex with zero, and continue with next one.
 				if sum >= 31:  #
 					while j < 4:
@@ -631,7 +638,7 @@ class Mesh(NamedObject):
 					bonePos += 1
 					j = 0
 					sum = 0
-		
+
 		# IndexBuffer
 		if m_CompressedMesh.m_Triangles.m_NumItems > 0:  #
 			self.m_IndexBuffer = m_CompressedMesh.m_Triangles.UnpackUInts()
@@ -641,16 +648,16 @@ class Mesh(NamedObject):
 			m_CompressedMesh.m_Colors.m_BitSize /= 4
 			tempColors = m_CompressedMesh.m_Colors.UnpackInts()
 			self.m_Colors = [
-					color / 255
-					for color in tempColors
+				color / 255
+				for color in tempColors
 			]
-	
+
 	def BuildFaces(self):
 		for m_SubMesh in self.m_SubMeshes:
 			firstIndex = m_SubMesh.firstByte // 2
 			if not self.m_Use16BitIndices:
 				firstIndex /= 2
-			
+
 			if m_SubMesh.topology == 0:
 				for i in range(0, m_SubMesh.indexCount, 3):
 					self.m_Indices.append(self.m_IndexBuffer[firstIndex + i])
@@ -662,18 +669,18 @@ class Mesh(NamedObject):
 					fa = self.m_IndexBuffer[firstIndex + i]
 					fb = self.m_IndexBuffer[firstIndex + i + 1]
 					fc = self.m_IndexBuffer[firstIndex + i + 2]
-					
+
 					if (fa != fb) and (fa != fc) and (fc != fb):
 						self.m_Indices.append(fa)
 						self.m_Indices.extend([fc, fb] if i % 2 else [fb, fc])
 						j += 1
 				# fix indexCount
 				m_SubMesh.indexCount = j * 3
-	
+
 	def InitMSkin(self):
 		self.m_Skin = [
-				BoneWeights4()
-				for _ in range(self.m_VertexCount)
+			BoneWeights4()
+			for _ in range(self.m_VertexCount)
 		]
 
 
@@ -695,7 +702,7 @@ class MeshHelper:
 			return 4
 		else:
 			return 0
-	
+
 	def BytesToFloatArray(inputBytes, size):
 		result = []
 		for i in range(math.ceil(len(inputBytes) / size)):
@@ -703,14 +710,15 @@ class MeshHelper:
 			if size == 1:
 				value = inputBytes[i] / 255.0
 			elif size == 2:
-				value = float.from_bytes(inputBytes[i * 2:i * 2 + 2], byteorder = 'big', signed = True)  # return Half.ToHalf((ushort)BitConverter.ToInt16(value, startIndex));
+				value = float.from_bytes(inputBytes[i * 2:i * 2 + 2], byteorder='big',
+										 signed=True)  # return Half.ToHalf((ushort)BitConverter.ToInt16(value, startIndex));
 			elif size == 4:
-				value = float.from_bytes(inputBytes[i * 4:i * 4 + 4], byteorder = 'big', signed = True)
+				value = float.from_bytes(inputBytes[i * 4:i * 4 + 4], byteorder='big', signed=True)
 			result[i] = value
 		return result
-	
+
 	def BytesToIntArray(inputBytes):
 		return [
-				int.from_bytes(inputBytes[i:i + 4], byteorder = 'big', signed = True)
-				for i in range(0, len(inputBytes), 4)
+			int.from_bytes(inputBytes[i:i + 4], byteorder='big', signed=True)
+			for i in range(0, len(inputBytes), 4)
 		]
